@@ -10,7 +10,7 @@ from strictdoc.backend.sdoc.models.document_grammar import (
     GrammarElement,
 )
 from strictdoc.backend.sdoc.models.object_factory import SDocObjectFactory
-from strictdoc.backend.sdoc.models.reference import Reference
+from strictdoc.backend.sdoc.models.reference import ParentReqReference
 from strictdoc.backend.sdoc.models.requirement import (
     RequirementField,
     Requirement,
@@ -125,15 +125,7 @@ class ExcelToSDocConverter:
 
     @staticmethod
     def create_document(title: Optional[str], extra_header_pairs) -> Document:
-        document_config = DocumentConfig(
-            parent=None,
-            version=None,
-            uid=None,
-            markup=None,
-            auto_levels=None,
-            requirement_style=None,
-            requirement_in_toc=None,
-        )
+        document_config = DocumentConfig.default_config(None)
         document_title = title if title else "<No title>"
         document = Document(document_title, document_config, None, [], [])
 
@@ -192,7 +184,7 @@ class ExcelToSDocConverter:
             comments=comments,
         )
         if parent_uid is not None:
-            reference = Reference(template_requirement, "Parent", parent_uid)
+            reference = ParentReqReference(template_requirement, parent_uid)
 
             requirement_field = RequirementField(
                 parent=template_requirement,
