@@ -35,12 +35,18 @@ from strictdoc.backend.reqif.sdoc_reqif_fields import (
 )
 from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.backend.sdoc.models.document_grammar import DocumentGrammar
-from strictdoc.backend.sdoc.models.requirement import Requirement
+from strictdoc.backend.sdoc.models.requirement import (
+    Requirement,
+)
+from strictdoc.backend.sdoc.models.section import Section
 from strictdoc.backend.sdoc.models.type_system import (
     GrammarElementFieldString,
     GrammarElementFieldSingleChoice,
     GrammarElementField,
     GrammarElementFieldMultipleChoice,
+    RequirementFieldName,
+    ReferenceType,
+    GrammarElementFieldReference,
 )
 from strictdoc.backend.sdoc.writer import SDWriter
 from strictdoc.core.document_iterator import DocumentCachingIterator
@@ -88,6 +94,9 @@ class SDocToReqIFObjectConverter:
         data_types_lookup = {}
         document: Document
         for document in document_tree.document_list:
+            document_spec_object_type = (
+                SDOC_SPEC_OBJECT_TYPE_SINGLETON + "_" + uuid.uuid4().hex
+            )
             for element in document.grammar.elements:
                 for field in element.fields:
                     if isinstance(field, GrammarElementFieldString):
@@ -155,11 +164,31 @@ class SDocToReqIFObjectConverter:
                         data_types_lookup[
                             StrictDocReqIFTypes.MULTI_CHOICE.value
                         ] = data_type.identifier
+                    elif isinstance(field, GrammarElementFieldReference):
+                        # TODO: implement correct reqIF Encoding for
+                        #  GrammarElementFieldReference. Treat as
+                        #  GrammarElementFieldString for now.
+                        if (
+                            StrictDocReqIFTypes.SINGLE_LINE_STRING.value
+                            in data_types_lookup
+                        ):
+                            continue
+                        data_type = ReqIFDataTypeDefinitionString.create(
+                            identifier=(
+                                StrictDocReqIFTypes.SINGLE_LINE_STRING.value
+                            ),
+                        )
+                        data_types.append(data_type)
+                        data_types_lookup[
+                            StrictDocReqIFTypes.SINGLE_LINE_STRING.value
+                        ] = data_type.identifier
                     else:
                         raise NotImplementedError(field) from None
 
             document_spec_types = cls._convert_document_grammar_to_spec_types(
-                grammar=document.grammar, data_types_lookup=data_types_lookup
+                grammar=document.grammar,
+                data_types_lookup=data_types_lookup,
+                document_spec_object_type=document_spec_object_type,
             )
             spec_types.extend(document_spec_types)
 
@@ -189,7 +218,31 @@ class SDocToReqIFObjectConverter:
                 ref_then_children_order=True,
                 level=0,
             )
+
             current_hierarchy = root_hierarchy
+            if len(document.free_texts) > 0:
+                # fmt: off
+                document_free_text_spec_object = (
+                    SDocToReqIFObjectConverter
+                    ._convert_document_free_text_to_spec_object(
+                        document,
+                        document_spec_object_type=document_spec_object_type
+                    )
+                )
+                # fmt: on
+                spec_objects.append(document_free_text_spec_object)
+                hierarchy = ReqIFSpecHierarchy(
+                    xml_node=None,
+                    is_self_closed=False,
+                    identifier=generate_unique_identifier("SPEC-HIERARCHY"),
+                    last_change=None,
+                    long_name=None,
+                    spec_object=document_free_text_spec_object.identifier,
+                    children=[],
+                    ref_then_children_order=True,
+                    level=document.ng_level + 1,
+                )
+                current_hierarchy.add_child(hierarchy)
             for node in document_iterator.all_content():
                 if node.is_composite_requirement:
                     raise NotImplementedError(
@@ -198,34 +251,15 @@ class SDocToReqIFObjectConverter:
                         node,
                     )
                 if node.is_section:
-                    attributes = []
-                    title_attribute = SpecObjectAttribute(
-                        xml_node=None,
-                        attribute_type=SpecObjectAttributeType.STRING,
-                        definition_ref=ReqIFChapterField.CHAPTER_NAME,
-                        value=node.title,
-                    )
-                    attributes.append(title_attribute)
-                    if len(node.free_texts) > 0:
-                        free_text_value = escape(
-                            SDWriter.print_free_text_content(node.free_texts[0])
+                    # fmt: off
+                    spec_object = (
+                        SDocToReqIFObjectConverter
+                        ._convert_section_to_spec_object(
+                            node,
+                            document_spec_object_type,
                         )
-                        free_text_attribute = SpecObjectAttribute(
-                            xml_node=None,
-                            attribute_type=SpecObjectAttributeType.STRING,
-                            definition_ref=ReqIFChapterField.TEXT,
-                            value=free_text_value,
-                        )
-                        attributes.append(free_text_attribute)
-                    spec_object = ReqIFSpecObject(
-                        xml_node=None,
-                        description=None,
-                        identifier=generate_unique_identifier("SECTION"),
-                        last_change=None,
-                        long_name=None,
-                        spec_object_type=SDOC_SPEC_OBJECT_TYPE_SINGLETON,
-                        attributes=attributes,
                     )
+                    # fmt: on
                     spec_objects.append(spec_object)
                     hierarchy = ReqIFSpecHierarchy(
                         xml_node=None,
@@ -259,6 +293,7 @@ class SDocToReqIFObjectConverter:
                         requirement=node,
                         grammar=document.grammar,
                         context=context,
+                        document_spec_object_type=document_spec_object_type,
                     )
                     spec_objects.append(spec_object)
                     hierarchy = ReqIFSpecHierarchy(
@@ -323,6 +358,7 @@ class SDocToReqIFObjectConverter:
         core_content_or_none = ReqIFCoreContent(reqif_reqif_content)
 
         namespace_info: ReqIFNamespaceInfo = ReqIFNamespaceInfo(
+            original_reqif_tag_dump=None,
             doctype_is_present=True,
             encoding="UTF-8",
             namespace=namespace,
@@ -360,24 +396,96 @@ class SDocToReqIFObjectConverter:
         )
         return reqif_bundle
 
+    @classmethod
+    def _convert_document_free_text_to_spec_object(
+        cls, document: Document, document_spec_object_type: str
+    ) -> ReqIFSpecObject:
+        assert isinstance(document, Document)
+        assert len(document.free_texts) > 0
+        attributes = []
+        # See SDOC_IMPL_1.
+        title_attribute = SpecObjectAttribute(
+            xml_node=None,
+            attribute_type=SpecObjectAttributeType.STRING,
+            definition_ref=ReqIFChapterField.CHAPTER_NAME,
+            value="Abstract",
+        )
+        attributes.append(title_attribute)
+        free_text_value = escape(
+            SDWriter.print_free_text_content(document.free_texts[0])
+        )
+        free_text_attribute = SpecObjectAttribute(
+            xml_node=None,
+            attribute_type=SpecObjectAttributeType.STRING,
+            definition_ref=ReqIFChapterField.TEXT,
+            value=free_text_value,
+        )
+        attributes.append(free_text_attribute)
+        spec_object = ReqIFSpecObject(
+            xml_node=None,
+            description=None,
+            identifier=generate_unique_identifier("DOCUMENT_FREETEXT"),
+            last_change=None,
+            long_name=None,
+            spec_object_type=document_spec_object_type,
+            attributes=attributes,
+        )
+        return spec_object
+
+    @classmethod
+    def _convert_section_to_spec_object(
+        cls, section: Section, document_spec_object_type: str
+    ) -> ReqIFSpecObject:
+        assert isinstance(section, Section)
+        attributes = []
+        title_attribute = SpecObjectAttribute(
+            xml_node=None,
+            attribute_type=SpecObjectAttributeType.STRING,
+            definition_ref=ReqIFChapterField.CHAPTER_NAME,
+            value=section.title,
+        )
+        attributes.append(title_attribute)
+        if len(section.free_texts) > 0:
+            free_text_value = escape(
+                SDWriter.print_free_text_content(section.free_texts[0])
+            )
+            free_text_attribute = SpecObjectAttribute(
+                xml_node=None,
+                attribute_type=SpecObjectAttributeType.STRING,
+                definition_ref=ReqIFChapterField.TEXT,
+                value=free_text_value,
+            )
+            attributes.append(free_text_attribute)
+        spec_object = ReqIFSpecObject(
+            xml_node=None,
+            description=None,
+            identifier=generate_unique_identifier("SECTION"),
+            last_change=None,
+            long_name=None,
+            spec_object_type=document_spec_object_type,
+            attributes=attributes,
+        )
+        return spec_object
+
     @classmethod
     def _convert_requirement_to_spec_object(
         cls,
         requirement: Requirement,
         grammar: DocumentGrammar,
         context: SDocToReqIFBuildContext,
+        document_spec_object_type: str,
     ) -> ReqIFSpecObject:
         requirement_identifier = generate_unique_identifier("REQUIREMENT")
         grammar_element = grammar.elements_by_type[requirement.requirement_type]
 
         attributes: List[SpecObjectAttribute] = []
         for field in requirement.fields:
-            if field.field_name == "REFS":
+            if field.field_name == RequirementFieldName.REFS:
                 parent_references = []
                 for reference in field.field_value_references:
-                    if reference.ref_type != "Parent":
+                    if reference.ref_type != ReferenceType.PARENT:
                         continue
-                    parent_references.append(reference.path)
+                    parent_references.append(reference.ref_uid)
                     context.map_uid_to_parent_uids[
                         requirement.uid
                     ] = parent_references
@@ -418,7 +526,7 @@ class SDocToReqIFObjectConverter:
 
         spec_object = ReqIFSpecObject.create(
             identifier=requirement_identifier,
-            spec_object_type=SDOC_SPEC_OBJECT_TYPE_SINGLETON,
+            spec_object_type=document_spec_object_type,
             attributes=attributes,
         )
         context.map_uid_to_spec_objects[requirement.uid] = spec_object
@@ -426,7 +534,10 @@ class SDocToReqIFObjectConverter:
 
     @classmethod
     def _convert_document_grammar_to_spec_types(
-        cls, grammar: DocumentGrammar, data_types_lookup
+        cls,
+        grammar: DocumentGrammar,
+        data_types_lookup,
+        document_spec_object_type: str,
     ):
         spec_object_types: List = []
 
@@ -475,6 +586,22 @@ class SDocToReqIFObjectConverter:
                         long_name=field.title,
                         multi_valued=True,
                     )
+                elif isinstance(field, GrammarElementFieldReference):
+                    # TODO: implement correct reqIF Encoding for
+                    #  GrammarElementFieldReference. Treat as
+                    #  GrammarElementFieldString for now.
+                    field_title = field.title
+                    if field_title in SDocRequirementReservedField.SET:
+                        field_title = SDOC_TO_REQIF_FIELD_MAP[field_title]
+                    attribute = SpecAttributeDefinition.create(
+                        attribute_type=SpecObjectAttributeType.STRING,
+                        identifier=field_title,
+                        datatype_definition=(
+                            StrictDocReqIFTypes.SINGLE_LINE_STRING.value
+                        ),
+                        long_name=field_title,
+                    )
+
                 else:
                     raise NotImplementedError(field) from None
                 attribute_definitions.append(attribute)
@@ -491,7 +618,7 @@ class SDocToReqIFObjectConverter:
             attribute_definitions.append(chapter_name_attribute)
 
             spec_object_type = ReqIFSpecObjectType.create(
-                identifier=SDOC_SPEC_OBJECT_TYPE_SINGLETON,
+                identifier=document_spec_object_type,
                 long_name=element.tag,
                 attribute_definitions=attribute_definitions,
             )
