@@ -1,3 +1,4 @@
+import uuid
 from typing import Optional
 
 from strictdoc.backend.sdoc.models.document_config import DocumentConfig
@@ -22,9 +23,10 @@ class Document:  # pylint: disable=too-many-instance-attributes
         self.free_texts = free_texts
         self.section_contents = section_contents
 
-        self.ng_level = 0
+        self.ng_level: int = 0
         self.ng_needs_generation = False
         self.meta: Optional[DocumentMeta] = None
+        self.node_id = uuid.uuid4().hex
 
     def __str__(self):
         return (
