@@ -1,3 +1,4 @@
+import uuid
 from collections import OrderedDict
 from typing import Optional, List
 
@@ -7,7 +8,6 @@ from strictdoc.backend.sdoc.models.reference import Reference
 from strictdoc.backend.sdoc.models.type_system import (
     RequirementFieldName,
     RESERVED_NON_META_FIELDS,
-    ReferenceType,
 )
 
 MULTILINE_WORD_THRESHOLD = 6
@@ -29,8 +29,27 @@ class RequirementField:
     ):
         self.parent = parent
         self.field_name = field_name
-        self.field_value: Optional[str] = field_value
+
+        if field_value_multiline is not None:
+            rstripped_field_value_multiline = field_value_multiline.rstrip()
+
+            # Edge case: empty multiline field should have one newline symbol.
+            # Example:
+            # COMMENT: >>>
+            #
+            # <<<
+            if (
+                len(rstripped_field_value_multiline) == 0
+                and len(field_value_multiline) != 0
+            ):
+                field_value_multiline = "\n"
+            else:
+                field_value_multiline = rstripped_field_value_multiline
+
         self.field_value_multiline: Optional[str] = field_value_multiline
+
+        self.field_value: Optional[str] = field_value
+
         self.field_value_references: Optional[
             List[Reference]
         ] = field_value_references
@@ -106,13 +125,14 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
             ][0].field_value_references
             assert references_opt is not None
             references = references_opt
+
         if RequirementFieldName.TITLE in ordered_fields_lookup:
             title = ordered_fields_lookup[RequirementFieldName.TITLE][
                 0
             ].field_value
         if RequirementFieldName.STATEMENT in ordered_fields_lookup:
             field = ordered_fields_lookup[RequirementFieldName.STATEMENT][0]
-            if field.field_value_multiline:
+            if field.field_value_multiline is not None:
                 statement_multiline = field.field_value_multiline
             else:
                 statement = field.field_value
@@ -127,7 +147,7 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
                 RequirementFieldName.COMMENT
             ]:
                 field = comment_field
-                if field.field_value_multiline:
+                if field.field_value_multiline is not None:
                     comments.append(
                         RequirementComment(
                             parent=self,
@@ -162,15 +182,8 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
         self.comments = comments
         self.requirements = requirements
 
-        # For multiline fields:
-        # Due to the details of how matching single vs multistring lines is
-        # implemented, the rstrip() is done to simplify SDoc code generation.
-        self.statement_multiline: Optional[str] = (
-            statement_multiline.rstrip() if statement_multiline else None
-        )
-        self.rationale_multiline = (
-            rationale_multiline.rstrip() if rationale_multiline else None
-        )
+        self.statement_multiline: Optional[str] = statement_multiline
+        self.rationale_multiline: Optional[str] = rationale_multiline
 
         # TODO: Is it worth to move this to dedicated Presenter* classes to
         # keep this class textx-only?
@@ -183,6 +196,8 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
         self.ng_document_reference: Optional[DocumentReference] = None
         self.context = RequirementContext()
 
+        self.node_id = uuid.uuid4().hex
+
     def __str__(self):
         return (
             f"{self.__class__.__name__}("
@@ -218,21 +233,29 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
             self.ng_document_reference.get_document().config.is_inline_requirements()  # noqa: E501
         )
 
-    def get_requirement_references(self):
+    def has_requirement_references(self, ref_type):
+        if not self.references or len(self.references) == 0:
+            return False
+        for reference in self.references:
+            if reference.ref_type == ref_type:
+                return True
+        return False
+
+    def get_requirement_references(self, ref_type):
         if not self.references or len(self.references) == 0:
             return []
         references = []
         for reference in self.references:
-            if reference.ref_type != ReferenceType.PARENT:
+            if reference.ref_type != ref_type:
                 continue
             references.append(reference)
         return references
 
-    def get_statement_single_or_multiline(self):
-        if self.statement:
-            return self.statement
-        if self.statement_multiline:
+    def get_statement_single_or_multiline(self) -> Optional[str]:
+        if self.statement_multiline is not None:
             return self.statement_multiline
+        if self.statement is not None:
+            return self.statement
         return None
 
     def get_rationale_single_or_multiline(self):
@@ -242,13 +265,6 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
             return self.rationale_multiline
         return None
 
-    def append_to_multiline_statement(self, new_statement):
-        statement_field = self.ordered_fields_lookup[
-            RequirementFieldName.STATEMENT
-        ][0]
-        statement_field.field_value_multiline += new_statement.rstrip()
-        self.statement_multiline = statement_field.field_value_multiline
-
     def enumerate_fields(self):
         requirement_fields = self.ordered_fields_lookup.values()
         for requirement_field in requirement_fields:
@@ -342,12 +358,15 @@ class RequirementComment:
     ):
         self.parent = parent
         self.comment_single: Optional[str] = comment_single
+        self.comment_multiline: Optional[str] = comment_multiline
 
-        # Due to the details of how matching single vs multistring lines is
-        # implemented, the rstrip() is done to simplify SDoc code generation.
-        self.comment_multiline: Optional[str] = (
-            comment_multiline.rstrip() if comment_multiline else None
-        )
+        # The case when both are None is when a multi-line field has no text
+        # but only an empty space:
+        # [REQUIREMENT]
+        # COMMENT: <empty space symbol>
+        # assert comment_single is not None or comment_multiline is not None
+        # TODO: One solution to simplify this would be to disallow empty fields
+        # in the grammar completely.
 
     def __str__(self):
         return (
